summaryrefslogtreecommitdiffstats
path: root/kwin/useractions.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/useractions.cpp')
-rw-r--r--kwin/useractions.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kwin/useractions.cpp b/kwin/useractions.cpp
index 2821658c2..50e495496 100644
--- a/kwin/useractions.cpp
+++ b/kwin/useractions.cpp
@@ -229,7 +229,7 @@ void Workspace::desktopPopupAboutToShow()
id = desk_popup->insertItem(
basic_name
.arg(i)
- .arg( desktopName(i).replace( '&', "&&" )),
+ .arg( desktopName(i).tqreplace( '&', "&&" )),
i );
if ( active_popup_client &&
!active_popup_client->isOnAllDesktops() && active_popup_client->desktop() == i )
@@ -293,7 +293,7 @@ void Workspace::setupWindowShortcut( Client* c )
client_keys_client = c;
connect( client_keys_dialog, TQT_SIGNAL( dialogDone( bool )), TQT_SLOT( setupWindowShortcutDone( bool )));
TQRect r = clientArea( ScreenArea, c );
- TQSize size = client_keys_dialog->sizeHint();
+ TQSize size = client_keys_dialog->tqsizeHint();
TQPoint pos = c->pos() + c->clientPos();
if( pos.x() + size.width() >= r.right())
pos.setX( r.right() - size.width());
@@ -1044,8 +1044,8 @@ void Workspace::showWindowMenu( const TQRect &pos, Client* cl )
else
{
TQRect area = clientArea(ScreenArea, TQPoint(x, y), currentDesktop());
- clientPopupAboutToShow(); // needed for sizeHint() to be correct :-/
- int popupHeight = p->sizeHint().height();
+ clientPopupAboutToShow(); // needed for tqsizeHint() to be correct :-/
+ int popupHeight = p->tqsizeHint().height();
if (y + popupHeight < area.height())
p->exec( TQPoint( x, y ) );
else
@@ -1093,7 +1093,7 @@ void Client::setShortcut( const TQString& _cut )
// Format:
// base+(abcdef)<space>base+(abcdef)
// E.g. Alt+Ctrl+(ABCDEF) Win+X,Win+(ABCDEF)
- if( !cut.contains( '(' ) && !cut.contains( ')' ) && !cut.contains( ' ' ))
+ if( !cut.tqcontains( '(' ) && !cut.tqcontains( ')' ) && !cut.tqcontains( ' ' ))
{
if( workspace()->shortcutAvailable( KShortcut( cut ), this ))
setShortcutInternal( KShortcut( cut ));